@@ -3,7 +3,7 @@ package Sub::Lib;
 use strict;
 use warnings;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 sub new {
   my ($class, @args) = @_;
@@ -71,6 +71,42 @@ sub call {
   return $object->$sub(@args);
 }
 
+sub void {
+  my ($self, $name) = @_;
+
+  my $_lib = $self->();
+  my $sub = exists $_lib->{$name}
+    ? $_lib->{$name}
+    : sub { return }
+  ;
+
+  return $sub;
+}
+
+sub curry {
+  my ($self, $name, @args) = @_;
+
+  my $sub = $self->($name);
+  return sub { $sub->(@args, @_) };
+}
+
+sub o {
+  my ($self, $name, $object, @args) = @_;
+
+  my $sub = $self->($name);
+  return sub { $object->$sub(@args, @_) };
+}
+
+sub y {
+  my ($self, $name, $sub, @args) = @_;
+
+  die "code reference required for lambda\n"
+    unless 'CODE' eq ref $sub;
+
+  return sub { $sub->( $self->($name), @args, @_ ) }
+}
+
+
 1
 __END__
 
@@ -100,17 +136,41 @@ Sub::Lib - Stuff sub-routines into a run-time namespace.  Because.  Reasons.
   $lib->run('warn', 'This is for warnings');
 
   # or via some oo sugar
-  $lib->('method', sub {my ($self, @args) = @_; $self->run(@args);});
+  $lib->('method', sub {
+    my ($self, $name, @args) = @_;
+    $self->run($name, @args);
+  });
+  # calls the 'method' sub-routine from the library as an object
+  # method on $lib.  attaches to objects like a virus.
   $lib->call('method', $lib, 'info', "Have you seen?  Oh I've seen.");
 
   # cheeseburger
   {
     my $sub = $lib->has('warn');
-    $sub->("I can has.")
+    $sub->('I can has.')
       if $sub;
   }
 
-  # scan the library
+  # in case you don't like exceptions
+  $lib->void('info')->('This has a high probability of working');
+  $lib->void('ofni')->('Hidden messages go here');
+
+  # why not?
+  $lib->curry('warn', 'I know stuff now')->('and later');
+
+  # why not?  for objects.
+  my $o = $lib->o('method', $lib, 'info');
+  $o->('I think I am confused');
+
+  # closures allow bending time
+  my $y = $lib->y('apex', sub {
+    my ($sub, @args) = @_;
+    $sub->('I can see forever', @args);
+  }, 'or something.');
+  $lib->('apex',  sub {$lib->('log')->('apex:', @_)});
+  $y->('can you?');
+
+  # you have been warned
   $lib->('info')->('installed subs:', join(', ', keys %{$lib->()}));
 
 =head1 DESCRIPTION
@@ -157,6 +217,33 @@ a method to the object in C<$object>.  This is similar to C<run()> above
 but uses Perl's object semantics.  Additional arguments are passed to
 the method.
 
+=head2 C<void($name)>
+
+Either returns the sub-routine installed in the library identified by
+C<$name> or returns a void sub-routine.  This is useful if you want
+to blindly call sub-routines and not worry if they exist.  It is
+debatable how useful that is in itself.
+
+=head2 C<curry($name, [LIST])>
+
+Returns a sub-routine that, when called, will execute the sub-routine
+installed in the library identified by C<$name> with arguments in C<LIST>
+prepended.  Additional arguments to the call itself are also appended.
+
+=head2 C<o($name, $object, [LIST])>
+
+Similar to C<curry()> but the sub-routine that is returned will execute a
+method call on the object specified by C<$object>.
+
+=head2 C<y($name, $sub, [LIST])>
+
+Creates an anonymous sub-routine that, when executed, will run the C<CODE>
+reference identified by C<$sub> passing in the sub-routine installed in
+the library under C<$name>.  Arguments passed in C<LIST> will be curried
+along with arguments to the call itself.  Unlike other methods, C<y()>
+does not require C<$name> to be installed when called in order to delay
+execution for as long as possible.
+
 =head1 AUTHOR
 
 jason hord E<lt>pravus@cpan.orgE<gt>
